Tutorials
=========

Below you will find some lessons on different aspects of the toolbox, sorted from
basic to expert level.

Beginner:

.. toctree::
  :maxdepth: 1

  getting_started/index
  visualization/index

Intermediate:

.. toctree::
  :maxdepth: 1

  switching_systems/index
  postprocessing/index

Expert:

.. toctree::
  :maxdepth: 1

  metaprocessing/index

